;; Generated package description from ada-mode.el  -*- no-byte-compile: t -*-
(define-package "ada-mode" "7.2.1.0.20220710.90937" "major-mode for editing Ada sources" '((uniquify-files "1.0.1") (wisi "3.1.8") (emacs "25.3")) :commit "1bed7479680d61733e2c171afd6f5655ca7a9d9e" :authors '(("Stephen Leake" . "stephen_leake@stephe-leake.org")) :maintainer '("Stephen Leake" . "stephen_leake@stephe-leake.org") :keywords '("languages" "ada") :url "http://www.nongnu.org/ada-mode/")
